__doc__ == """
**naclo** is a Python cleaning toolset for small molecule drug discovery datasets.
"""


from naclo.mol_stats import *
from naclo.mol_conversion import *
from naclo import fragments
from naclo import neutralize
from naclo import dataframes



import unittest
from naclo import fragments as frag
from naclo.mol_conversion import *


class TestFragments(unittest.TestCase):
    def test_frag_remover(self):
        # Test case
        test_smile = 'CCC.C.C'
        
        # Test all frag removing methods
        self.assertEqual(
            frag.mw(test_smile), 
            'CCC'
        )
        self.assertEqual(
            frag.atom_count(test_smile), 
            'CCC'
        )
        self.assertEqual(
            frag.carbon_count(test_smile),
            'CCC'
        )
        
    def test_remove_salts(self):
        # Test case
        test_mols = smiles_2_mols(['CN(C)C.Cl', 'CN(C)C.N'])
        
        # Test default salts [Cl,Br]
        self.assertEqual(
            mols_2_smiles(frag.remove_salts(test_mols)), 
            ['CN(C)C', 'CN(C)C.N']
        )
        
        # Test custom salts [N]
        self.assertEqual(
            mols_2_smiles(frag.remove_salts(test_mols, salts='[N]')), 
            ['CN(C)C.Cl', 'CN(C)C']
        )


if __name__ == '__main__':
    unittest.main()



import unittest
from naclo import mol_stats
from naclo import mol_conversion


class TestMolStats(unittest.TestCase):
    @classmethod
    def setUpClass(cls) -> None:
        cls.test_smile = 'CN=C=O'
        cls.test_mols = mol_conversion.smiles_2_mols([cls.test_smile, 'C'])
        return super().setUpClass()
    
    def test_carbon_num(self):
        self.assertEqual(
            mol_stats.carbon_num(self.test_smile),
            2
        )
    
    def test_mol_weights(self):
        self.assertEqual(
            list(map(lambda x: round(x, 3), mol_stats.mol_weights(self.test_mols))), 
            [57.021, 16.031]
        )


if __name__ == '__main__':
    unittest.main()



import unittest
import pandas as pd
from rdkit import Chem
from rdkit.Chem import PandasTools

import naclo
from naclo import dataframes


class TestDataframes(unittest.TestCase):
    @classmethod
    def setUpClass(cls) -> None:
        cls.test_df = pd.DataFrame({'a': [4, '5', '6'], 'b': ['6', '5', '4']})
        cls.mol_test_df = pd.DataFrame({
            'SMILES': ['O=C(O)C1(Sc2ccnc3ccc(Br)cc23)CCC1', 
                       'O=C(O)C1(Sc2ccnc3ccc(C4CC4)cc23)CCC1', 
                       'CC(C)(Sc1ccncc1-c1ccc(C#N)c2ccccc12)C(=O)O',
                       None],
            'Molecule': [Chem.MolFromSmiles('O=C(O)C1(Sc2ccnc3ccc(Br)cc23)CCC1'),
                         Chem.MolFromSmiles('O=C(O)C1(Sc2ccnc3ccc(C4CC4)cc23)CCC1'),
                         Chem.MolFromSmiles('CC(C)(Sc1ccncc1-c1ccc(C#N)c2ccccc12)C(=O)O'),
                         None],
            'InChi': [Chem.MolToInchiKey(Chem.MolFromSmiles('O=C(O)C1(Sc2ccnc3ccc(Br)cc23)CCC1')),
                      Chem.MolToInchiKey(Chem.MolFromSmiles('O=C(O)C1(Sc2ccnc3ccc(C4CC4)cc23)CCC1')),
                      Chem.MolToInchiKey(Chem.MolFromSmiles('CC(C)(Sc1ccncc1-c1ccc(C#N)c2ccccc12)C(=O)O')),
                      None]
        })
        
        cls.excel_df = pd.read_excel('test/excel_test_case.xlsx')
        cls.excel_df = dataframes.df_smiles_2_mols(cls.excel_df, 'Smiles', 'Molecule')
        cls.sdf_df = PandasTools.LoadSDF('test/sdf_test_case.sdf', molColName='Molecule')
        cls.sdf_df.ID = list(range(4))
        
        return super().setUpClass()
    
    def test_df_smiles_2_mols(self):
         # Test with dropna
        out1 = dataframes.df_smiles_2_mols(self.mol_test_df, 'SMILES', 'ROMol')
        assert out1.ROMol.map(Chem.MolToSmiles, na_action='ignore').equals(self.mol_test_df.Molecule.map(Chem.MolToSmiles, na_action='ignore').dropna())
        
        # Test without dropna
        out2 = dataframes.df_smiles_2_mols(self.mol_test_df, 'SMILES', 'ROMol', dropna=False)
        assert out2.ROMol.map(Chem.MolToSmiles, na_action='ignore').equals(self.mol_test_df.Molecule.map(Chem.MolToSmiles, na_action='ignore'))
    
    def test_df_mols_2_inchi_keys(self):
        # Test with dropna
        out1 = dataframes.df_mols_2_inchi_keys(self.mol_test_df, 'Molecule', 'inchi')
        assert out1.inchi.equals(self.mol_test_df.InChi.dropna())
        
        # Test without dropna
        out2 = dataframes.df_mols_2_inchi_keys(self.mol_test_df, 'Molecule', 'inchi', dropna=False)
        assert out2.inchi.equals(self.mol_test_df.InChi)
        
    def test_df_mols_2_smiles(self):
        # Test with dropna
        out1 = dataframes.df_mols_2_smiles(self.mol_test_df, 'Molecule', 'smiles')
        assert out1.smiles.equals(self.mol_test_df.SMILES.dropna())
        
        # Test without dropna
        out2 = dataframes.df_mols_2_smiles(self.mol_test_df, 'Molecule', 'smiles', dropna=False)
        assert out2.smiles.equals(self.mol_test_df.SMILES)
        
    def test_write_sdf(self):
        # Write new and load new
        dataframes.write_sdf(self.excel_df, 'test/sdf_test_out.sdf', mol_col_name='Molecule')
        load_sdf = PandasTools.LoadSDF('test/sdf_test_out.sdf', molColName='Molecule')
        
        # Ensure Mols are the same
        self.assertEqual(
            naclo.mols_2_smiles(load_sdf.Molecule),
            naclo.mols_2_smiles(self.sdf_df.Molecule)
        )
        
        # Ensure original SMILES are the same
        assert load_sdf.Smiles.equals(self.sdf_df.Smiles)
